Representing all fields for a SEQUENCE or SET type.
Structs
- Field
- Represents a field in a
SETorSEQUENCEtype. - Fields
- Represents all of the values that make up a given value in ASN.1.
Enums
- Field
Presence - The presence of a field in constructed type, used to determine whether to expect a given field when encoding or decoding, and how to react when it is not present.